@@ -110,7 +110,8 @@ class WeakNetworkConfig(object):
         t1 = time.time()
         while True:
             if time.time() - t1 > timeout:
-                raise Exception('get_device_ip:{} timeout:{}'.format(device['wda_url'], timeout))
+                logger.error('get_device_ip:{} timeout:{}'.format(device['wda_url'], timeout))
+                return None
             device_ip = self._stf.get_device_ip(device['wda_url'], self.platform)
             logger.info("get device_ip {}".format(device_ip))
             if device_ip:
